@@ -1,7 +1,7 @@
 Ext.Loader.setConfig({
     enabled : true,
     paths   : {
-        Ux : '/mastertek-api/sencha-touch-gpl/2.2.1/Ux'
+        Ux : '/static/sencha_touch/Ux'
     }
 });
 
@@ -30,7 +30,7 @@ Ext.require([
             method : 'GET'
         },
         language   : 'it',
-        tpl        : 'app/locales/{locale}.json',
+        tpl        : '/static/subscribe_touch/app/locales/{locale}.json',
         type       : 'ajax'
     });
 });
\ No newline at end of file
